enhanced_paginated_view library

Classes

EmptyWidgetConfig
A configuration class for the empty widget.
EnhancedConfig
Presentation and behavior configuration for EnhancedPaginatedView.
EnhancedDelegate<T>
Immutable data holder for EnhancedPaginatedView.
EnhancedPaginatedView<T>
This is the EnhancedPaginatedView widget. It provides a paginated view of items of type T.
EnhancedPaginationController
Tracks pagination state for an EnhancedPaginatedView.
ErrorLoadMoreConfig
Represents the configuration for handling error while loading more data.
ErrorPageConfig
Represents the configuration for an error page.
LoadingConfig
A configuration class for defining the loading widgets used in the enhanced paginated view.

Enums

EnhancedStatus
Represents the status of an enhanced paginated view.
EnhancedViewDirection
Enum representing the direction of an enhanced view.

Extensions

EnhancedDeduplication on Iterable<T>

Typedefs

EnhancedBoxBuilder<T> = Widget Function(List<T> data, ScrollPhysics physics, bool reverse, bool shrinkWrap)
Defines a typedef for a function that builds a widget with enhanced box properties.
EnhancedRefreshBuilder<T> = Widget Function(BuildContext context, Future<void> onRefresh(), Widget child)
EnhancedSliverBuilder<T> = Widget Function(BuildContext context, List<T> data)
Defines a typedef for a function that builds a sliver widget with enhanced properties.